Learn R Programming

ebTobit (version 1.0.2)

new_ebTobit: Create a new ebTobit object

Description

Validate the provided elements and populate the object. Current methods require that gr is numeric for that calculation of posterior statistics (mean and mediod).

Usage

new_ebTobit(prior, gr, lik)

Value

an EBayesMat object containing at least the prior weights, corresponding grid/support points, and likelihood matrix relating the grid to the observations

Arguments

prior

numeric vector of non-negative weights (sums to one)

gr

numeric matrix of support points

lik

numeric matrix of likelihoods