Validate the provided elements and populate the object. Current methods
require that gr is numeric for that calculation of posterior
statistics (mean and mediod).
new_ebTobit(prior, gr, lik)an EBayesMat object containing at least the prior weights,
corresponding grid/support points, and likelihood matrix relating the grid to
the observations
numeric vector of non-negative weights (sums to one)
numeric matrix of support points
numeric matrix of likelihoods